<?php

/**
 * @file
 * Contains Drupal\naming\NamingConventionForm.
 */

namespace Drupal\naming;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\naming\Entity\NamingCategory;

/**
 * Base form for NamingConvention add and edit forms.
 */
class NamingConventionForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\naming\Entity\NamingConvention $naming_convention */
    $naming_convention = $this->getEntity();
    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $naming_convention->label(),
    ];
    $form['id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Route/Custom ID'),
      '#maxlength' => 255,
      '#required' => TRUE,
      '#default_value' => $naming_convention->id(),
    ];
    $form['content'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Content'),
      '#default_value' => $naming_convention->getContent()['value'],
      '#format' => $naming_convention->getContent()['format'] ?: filter_default_format(),
    ];
    $category_options = ['' => '<None>'];
    $categories = NamingCategory::loadMultiple();
    foreach ($categories as $category) {
      $category_options[$category->id()] = $category->label();
    }
    $form['category'] = [
      '#type' => 'select',
      '#title' => $this->t('Category'),
      '#options' => $category_options,
      '#default_value' => $naming_convention->getCategory(),
    ];
    $form['weight'] = [
      '#type' => 'weight',
      '#title' => $this->t('Weight'),
      '#default_value' => $naming_convention->getWeight(),
      '#delta' => 10,
      '#description' => $this->t('Used to sort naming conventions when generating documentation.'),
    ];
    return parent::form($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\naming\Entity\NamingConvention $naming_convention */
    $naming_convention = $this->getEntity();
    $naming_convention->save();

    $this->logger('naming')->notice('Naming convention @label saved.', ['@label' => $naming_convention->label()]);
    drupal_set_message($this->t('Naming convention %label saved.', ['%label' => $naming_convention->label()]));

    $form_state->setRedirect('entity.naming_convention.collection');
  }

}
