<?php

/**
 * @file
 * Contains \Drupal\naming\NamingConventionInterface.
 */

namespace Drupal\naming;

use Drupal\Core\Routing\RouteMatchInterface;
/**
 * Provides an interface defining a NamingConvention.
 */
interface NamingConventionInterface {

  /**
   * Returns the NamingConvention content.
   *
   * @return array
   *   The NamingConvention content.
   */
  public function getContent();

  /**
   * Returns the NamingConvention category.
   *
   * @return array
   *   The NamingConvention category.
   */
  public function getCategory();

  /**
   * Returns the NamingConvention weight.
   *
   * @return array
   *   The NamingConvention weight.
   */
  public function getWeight();

  /**
   * Get the URL for the naming convention.
   *
   * @return \Drupal\Core\Url|null
   *   A URL object or NULL if not URL is associated with this
   *   naming convention.
   */
  public function getUrl();

  /**
   * Load naming convention using route march.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   A route match.
   *
   * @return \Drupal\naming\NamingConventionInterface|NULL
   *   A naming convention
   */
  public static function loadFromRouteMatch(RouteMatchInterface $route_match);

}
